Struct amazon_sp_vendor_orders::models::order_acknowledgement_item::OrderAcknowledgementItem
source · [−]pub struct OrderAcknowledgementItem {
pub item_sequence_number: Option<String>,
pub amazon_product_identifier: Option<String>,
pub vendor_product_identifier: Option<String>,
pub ordered_quantity: Box<ItemQuantity>,
pub net_cost: Option<Box<Money>>,
pub list_price: Option<Box<Money>>,
pub discount_multiplier: Option<String>,
pub item_acknowledgements: Vec<OrderItemAcknowledgement>,
}Expand description
OrderAcknowledgementItem : Details of the item being acknowledged.
Fields
item_sequence_number: Option<String>Line item sequence number for the item.
amazon_product_identifier: Option<String>Amazon Standard Identification Number (ASIN) of an item.
vendor_product_identifier: Option<String>The vendor selected product identification of the item. Should be the same as was sent in the purchase order.
ordered_quantity: Box<ItemQuantity>net_cost: Option<Box<Money>>list_price: Option<Box<Money>>discount_multiplier: Option<String>The discount multiplier that should be applied to the price if a vendor sells books with a list price. This is a multiplier factor to arrive at a final discounted price. A multiplier of .90 would be the factor if a 10% discount is given.
item_acknowledgements: Vec<OrderItemAcknowledgement>This is used to indicate acknowledged quantity.
Implementations
sourceimpl OrderAcknowledgementItem
impl OrderAcknowledgementItem
sourcepub fn new(
ordered_quantity: ItemQuantity,
item_acknowledgements: Vec<OrderItemAcknowledgement>
) -> OrderAcknowledgementItem
pub fn new(
ordered_quantity: ItemQuantity,
item_acknowledgements: Vec<OrderItemAcknowledgement>
) -> OrderAcknowledgementItem
Details of the item being acknowledged.